
model = readCbModel('model.xml');

%%%flux in only%%%
rxnList = {
    'cpd00254_ext_b' %mg
    'cpd00009_ext_b' %phosphate
    'cpd00082_ext_b' %fructose
    'cpd00013_ext_b' %nh3
    'cpd00205_ext_b' %K
    'cpd10515_ext_b' %Fe2
    'cpd00099_ext_b' %Cl
    'cpd00030_ext_b' %Mn
    'cpd00034_ext_b' %Zn
    'cpd00058_ext_b' %Cu
    'cpd00149_ext_b' %Co
    'cpd10516_ext_b' %Fe3
    'cpd00081_ext_b' %sulfite   
    };
model = changeRxnBounds(model,rxnList,0,'u');


%%%flux out only%%%
rxnList = {
    'cpd00024_ext_b' %oxoglutarate
    'cpd00159_ext_b' %lactate
    'cpd15378_ext_b' %hydroxy-benzylalcohol
    'cpd00229_ext_b' %glycoaldehyde
    'cpd00363_ext_b' %ethanol
    'cpd00029_ext_b' %acetate
    'cpd00036_ext_b' %succinate
    'cpd01947_ext_b' %BDOH
    'cpd11416_ext_b' %biomass
    };
model = changeRxnBounds(model,rxnList,0,'l');


bioEQ = findRxnIDs(model,'bio1_c0');
ignoreBioComp = {
    'S_cpd00028_c0'     %	'Heme' %require oxygen for synthesis
    'S_cpd15560_c0'     %	'Ubiquinone-8'% only for aerobic
    'S_cpd00048_c0'     %   'sulfate' no way to convert sulfite to sulfate without byproduct
    'S_cpd17041_c0'		%	'Protein biosynthesis' %ignore
    'S_cpd17042_c0'		%	'DNA replication' %ignore
    'S_cpd17043_c0'		%	'RNA transcription' %ignore
    };
hitMets = findMetIDs(model,ignoreBioComp);
model.S(hitMets,bioEQ) = 0;


%%%constrain reversibilities
%%%stop NADPH making reactions%%
rxnList = {
    'rxn01302_c0'%1 NADP + 1 L-Homoserine = 1 H+ + 1 L-Aspartate4-semialdehyde + 1 NADPH
    'rxn00612_c0'%1 NADP + 1 Glycerol-3-phosphate = 1 H+ + 1 Glycerone-phosphate + 1 NADPH
    'rxn01281_c0'%1 NADP + 1 Glycerate = 1 Tartronate semialdehyde + 1 H+ + 1 NADPH
    'rxn00931_c0'%1 Prephenate + 1 NADP = 1 p-hydroxyphenylpyruvate + 1 CO2 + 1 NADPH
    'rxn01269_c0'%1 NADP + 1 L-Proline = 1 H+ + 1 1-Pyrroline-5-carboxylate + 1 NADPH
    };
model = changeRxnBounds(model,rxnList,0,'u');

%%%stop atp production%%
rxnList = {
    'rxn01492_c0'%1 D-fructose-1-phosphate + 1 ATP = 1 ADP + 1 D-fructose-1,6-bisphosphate
    'rxn00690_c0'%1 ATP + 1 Tetrahydrofolate + 1 Formate = 1 10-Formyltetrahydrofolate + 1 Phosphate + 1 ADP
    'rxn00114_c0'%1 ATP + 1 NH3 + 1 CO2 = 1 H+ + 1 Carbamoylphosphate + 1 ADP
    'rxn00506_c0'%1 Acetaldehyde + 1 NAD + 1 H2O = 1 Acetate + 1 NADH + 2.0 H+
    };
model = changeRxnBounds(model,rxnList,0,'l');

%control GAPDH alternative routes
% %activate GAPDH NADP
% model = changeRxnBounds(model,'rxn00779_mod_c0',0,'b');%GADPDH NAD
% model = changeRxnBounds(model,'rxn01100_c0',0,'b');%3PG kinase
% model = changeRxnBounds(model,'rxn00779_c0',-1000,'l');%GADPDH NADP
% %activate GAPDH NAD
% model = changeRxnBounds(model,'rxn00779_mod_c0',-1000,'l');%GADPDH NAD
% model = changeRxnBounds(model,'rxn01100_c0',0,'b');%3PG kinase
% model = changeRxnBounds(model,'rxn00779_c0',0,'b');%GADPDH NADP
% %activate 3PG kinase
% model = changeRxnBounds(model,'rxn00779_mod_c0',0,'b');%GADPDH NAD
% model = changeRxnBounds(model,'rxn00779_c0',0,'b');%GADPDH NADP

%%%make WL pathway uni-directional
model = changeRxnBounds(model,'rxn06149_c0',0,'l');%1 5-Methyltetrahydrofolate + 1 Corrinoid = 1 Tetrahydrofolate + 1 Methylcorrinoid
model = changeRxnBounds(model,'rxn04954_c0',0,'u');%use bifurcating M-thf reduc in the reduc dir

%test growth conditions%
% %CON1, growth on fructose
% model = changeRxnBounds(model,'cpd00082_ext_b',-10,'b');%fructose
% model = changeRxnBounds(model,'cpd00204_ext_b',0,'l');%CO
% model = changeRxnBounds(model,'cpd00011_ext_b',0,'l');%CO2
% model = changeRxnBounds(model,'cpd11640_ext_b',0,'l');%H2


%CON7, growth on RMG
model = changeRxnBounds(model,'cpd00082_ext_b',0,'l');%fructose
model = changeRxnBounds(model,'cpd00204_ext_b',-10,'l');%CO
model = changeRxnBounds(model,'cpd00011_ext_b',-10,'l');%CO2
model = changeRxnBounds(model,'cpd11640_ext_b',-1000,'l');%H2

model = changeObjective(model,'cpd11416_ext_b',1);%biomass
flux = optimizeCbModel(model,'max',0,1);

